package cn.com.infosec.asn1.x9;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import java.math.BigInteger;

public class X9FieldID extends ASN1Encodable implements X9ObjectIdentifiers {
   private DERObjectIdentifier id;
   private DERObject parameters;

   public X9FieldID(BigInteger primeP) {
      this.id = X9ObjectIdentifiers.prime_field;
      this.parameters = new DERInteger(primeP);
   }

   public X9FieldID(int m, int k1, int k2, int k3) {
      this.id = X9ObjectIdentifiers.characteristic_two_field;
      ASN1EncodableVector var5;
      ASN1EncodableVector var10001 = var5 = new ASN1EncodableVector;
      var10001.<init>();
      var10001.add(new DERInteger(m));
      if (k2 == 0) {
         var5.add(X9ObjectIdentifiers.tpBasis);
         var5.add(new DERInteger(k1));
      } else {
         var5.add(X9ObjectIdentifiers.ppBasis);
         ASN1EncodableVector m1;
         var10001 = m1 = new ASN1EncodableVector;
         var10001.<init>();
         var10001.add(new DERInteger(k1));
         var10001.add(new DERInteger(k2));
         var10001.add(new DERInteger(k3));
         var5.add(new DERSequence(m1));
      }

      X9FieldID var10000 = this;
      DERSequence var6;
      var6 = new DERSequence.<init>(var5);
      var10000.parameters = var6;
   }

   public X9FieldID(ASN1Sequence seq) {
      this.id = (DERObjectIdentifier)seq.getObjectAt(0);
      this.parameters = (DERObject)seq.getObjectAt(1);
   }

   public DERObjectIdentifier getIdentifier() {
      return this.id;
   }

   public DERObject getParameters() {
      return this.parameters;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.id);
      var10000.add(this.parameters);
      return new DERSequence(var1);
   }
}
